@@ -147,10 +147,12 @@ NS=cumsum(ns)
 NS=c(c(0,NS)[-(length(ns)+1)],NT)
 
 if(!space_dyn){
-data_tot=NULL
-for(k in 1:T) 
+data_tot=cc=NULL
+for(k in 1:T) {
+cc=rbind(cc,coords)
 data_tot=rbind(data_tot,cbind(rep(coordt[k],ns[k]),fit$data[k,]))
-data_tot=cbind(coords,data_tot,fit$X)
+}
+data_tot=cbind(cc,data_tot,fit$X)
 }
 
 
@@ -197,10 +199,14 @@ if(ncol(Xnew[[1]])==1) Xnew=NULL
 param=append(fit$param,fit$fixed)
 if(estimation) {
 
+print(datanew)
+print(coordx_dynnew)
+print(utt)
+print(Xnew)
            fit_s= GeoFit(data=datanew,coordx_dyn=coordx_dynnew,coordt=utt,
                             corrmodel=fit$corrmodel,X=Xnew,
                             likelihood=fit$likelihood,type=fit$type,grid=fit$grid,
-                            copula=fit$copula, #anisopars=fit$anisopars,#est.aniso=fit$est.aniso,
+                            copula=fit$copula, anisopars=fit$anisopars,est.aniso=fit$est.aniso,
                             model=model1,radius=fit$radius,n=fit$n,
                             local=fit$local,GPU=fit$GPU,
                             maxdist=fit$maxdist, neighb=fit$neighb,maxtime=fit$maxtime,distance=fit$distance,
